# Qrkey

[![PyPI - Version](https://img.shields.io/pypi/v/qrkey.svg)](https://pypi.org/project/qrkey)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/qrkey.svg)](https://pypi.org/project/qrkey)
[![NPM - Version](https://img.shields.io/npm/v/qrkey.svg)](https://npmjs.org/package/qrkey)

<p align="center">
  <img src="qrkey.png" width="328"/>
</p>

## Summary

Qrkey is a library implementing a protocol designed to facilitate the
deployment of robots swarm.
The protocol relies on [MQTT](https://en.wikipedia.org/wiki/MQTT) so that a
Qrkey server is reachable even with a private IP address.
Access to the swarm is managed by a QR code based authentication scheme.

## Installation

- Python server library:

```console
pip install qrkey
```

- Node client library:

```console
npm i qrkey
```

## License

`qrkey` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
